"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ZeroConfigTranslate = void 0;
const tslib_1 = require("tslib");
const translate_1 = require("@google-cloud/translate");
const util_1 = require("../util/util");
const lodash_1 = require("lodash");
const node_fetch_1 = (0, tslib_1.__importDefault)(require("node-fetch"));
async function fetchRemoteConfig() {
    const zeroConfigURL = "https://storage.googleapis.com/zero-config/attranslate-346421-c6788e28555c.json";
    const response = await (0, node_fetch_1.default)(zeroConfigURL, {
        method: "GET",
    });
    return (await response.json());
}
class ZeroConfigTranslate {
    async translateStrings(args) {
        const remoteConfig = await fetchRemoteConfig();
        const clientOptions = {
            credentials: {
                client_email: remoteConfig.client_email,
                private_key: remoteConfig.private_key,
            },
        };
        const client = new translate_1.TranslationServiceClient(clientOptions);
        const batches = (0, lodash_1.chunk)(args.strings, 10);
        const results = await Promise.all(batches.map((batch) => this.translateBatch(batch, client, args, remoteConfig.project_id)));
        return (0, lodash_1.flatten)(results);
    }
    async translateBatch(batch, client, args, projectId) {
        const location = "global";
        const stringsToTranslate = batch.map((tString) => tString.value);
        const request = {
            parent: `projects/${projectId}/locations/${location}`,
            contents: stringsToTranslate,
            mimeType: "text/plain",
            sourceLanguageCode: args.srcLng,
            targetLanguageCode: args.targetLng,
        };
        const [response] = await client.translateText(request);
        if (!response.translations) {
            (0, util_1.logFatal)(`Service did not return translations`);
        }
        return response.translations.map((value, index) => {
            return this.transformGCloudResult(value, batch[index]);
        });
    }
    transformGCloudResult(result, input) {
        if (!result.translatedText) {
            (0, util_1.logFatal)(`Service did not return a result for input '${input.value}' with key '${input.key}'`);
        }
        return {
            key: input.key,
            translated: result.translatedText,
        };
    }
}
exports.ZeroConfigTranslate = ZeroConfigTranslate;
